@@ -12,7 +12,7 @@
 
 import os
 
-from tempest_lib.common.utils import data_utils
+from tempest.lib.common.utils import data_utils
 
 from functional.common import test
 
